@@ -26,10 +26,12 @@
 #include <boost/checked_delete.hpp>
 
 #include <glib.h>
+#include <glibmm/i18n.h>
 
 #include "sharp/map.hpp"
 #include "sharp/directory.hpp"
 #include "sharp/dynamicmodule.hpp"
+#include "sharp/files.hpp"
 
 #include "addinmanager.hpp"
 #include "addinpreferencefactory.hpp"
@@ -64,19 +66,10 @@ namespace gnote {
 
     const bool is_first_run
                  = !sharp::directory_exists(m_addins_prefs_dir);
-    const std::string old_addins_dir
-                        = Glib::build_filename(IGnote::old_note_dir(),
-                                               "addins");
-    const bool migration_needed
-                 = is_first_run
-                   && sharp::directory_exists(old_addins_dir);
 
     if (is_first_run)
       g_mkdir_with_parents(m_addins_prefs_dir.c_str(), S_IRWXU);
 
-    if (migration_needed)
-      migrate_addins(old_addins_dir);
-
     initialize_sharp_addins();
   }
 
@@ -95,16 +88,14 @@ namespace gnote {
     }
   }
 
-  void AddinManager::add_note_addin_info(
-                       const sharp::DynamicModule * dmod)
+  void AddinManager::add_note_addin_info(const std::string & id,
+                                         const sharp::DynamicModule * dmod)
   {
-    const char * const id = dmod->id();
-
     {
       const IdInfoMap::const_iterator iter
                                         = m_note_addin_infos.find(id);
       if (m_note_addin_infos.end() != iter) {
-        ERR_OUT("NoteAddin info %s already present", id);
+        ERR_OUT(_("Note add-in info %s already present"), id.c_str());
         return;
       }
     }
@@ -112,11 +103,11 @@ namespace gnote {
     sharp::IfaceFactoryBase * const f = dmod->query_interface(
                                           NoteAddin::IFACE_NAME);
     if(!f) {
-      ERR_OUT("does not implement %s", NoteAddin::IFACE_NAME);
+      ERR_OUT(_("%s does not implement %s"), id.c_str(), NoteAddin::IFACE_NAME);
       return;
     }
 
-    m_note_addin_infos.insert(std::make_pair(std::string(id), f));
+    m_note_addin_infos.insert(std::make_pair(id, f));
 
     {
       for(NoteAddinMap::iterator iter = m_note_addins.begin();
@@ -124,7 +115,7 @@ namespace gnote {
         IdAddinMap & id_addin_map = iter->second;
         IdAddinMap::const_iterator it = id_addin_map.find(id);
         if (id_addin_map.end() != it) {
-          ERR_OUT("NoteAddin %s already present", id);
+          ERR_OUT(_("Note add-in %s already present"), id.c_str());
           continue;
         }
 
@@ -138,15 +129,12 @@ namespace gnote {
     }
   }
 
-  void AddinManager::erase_note_addin_info(
-                       const sharp::DynamicModule * dmod)
+  void AddinManager::erase_note_addin_info(const std::string & id)
   {
-    const char * const id = dmod->id();
-
     {
       const IdInfoMap::iterator iter = m_note_addin_infos.find(id);
       if (m_note_addin_infos.end() == iter) {
-        ERR_OUT("NoteAddin info %s absent", id);
+        ERR_OUT(_("Note add-in info %s is absent"), id.c_str());
         return;
       }
 
@@ -159,7 +147,7 @@ namespace gnote {
         IdAddinMap & id_addin_map = iter->second;
         IdAddinMap::iterator it = id_addin_map.find(id);
         if (id_addin_map.end() == it) {
-          ERR_OUT("NoteAddin %s absent", id);
+          ERR_OUT(_("Note add-in %s is absent"), id.c_str());
           continue;
         }
 
@@ -172,6 +160,58 @@ namespace gnote {
     }
   }
 
+  void AddinManager::load_addin_infos(const std::string & global_path,
+                                      const std::string & local_path)
+  {
+    load_addin_infos(global_path);
+    load_addin_infos(local_path);
+  }
+
+  void AddinManager::load_addin_infos(const std::string & path)
+  {
+    std::list<std::string> files;
+    sharp::directory_get_files_with_ext(path, ".desktop", files);
+    for(std::list<std::string>::iterator iter = files.begin(); iter != files.end(); ++iter) {
+      try {
+        AddinInfo addin_info(*iter);
+        std::string module = Glib::build_filename(path, addin_info.addin_module());
+        if(sharp::file_exists(module + "." + G_MODULE_SUFFIX)) {
+          addin_info.addin_module(module);
+          m_addin_infos[addin_info.id()] = addin_info;
+        }
+        else {
+          ERR_OUT(_("Failed to find module %s for addin %s"), addin_info.id().c_str(), module.c_str());
+        }
+      }
+      catch(std::exception & e) {
+        ERR_OUT(_("Failed to load addin info for %s: %s"), iter->c_str(), e.what());
+      }
+    }
+  }
+
+  void AddinManager::get_enabled_addins(std::list<std::string> & addins) const
+  {
+    bool global_addins_prefs_loaded = true;
+    Glib::KeyFile global_addins_prefs;
+    try {
+      global_addins_prefs.load_from_file(m_addins_prefs_file);
+    }
+    catch(Glib::Error & not_loaded) {
+      global_addins_prefs_loaded = false;
+    }
+
+    for(AddinInfoMap::const_iterator iter = m_addin_infos.begin(); iter != m_addin_infos.end(); ++iter) {
+      if(global_addins_prefs_loaded && global_addins_prefs.has_key("Enabled", iter->first)) {
+        if(global_addins_prefs.get_boolean("Enabled", iter->first)) {
+          addins.push_back(iter->second.addin_module());
+        }
+      }
+      else if(iter->second.default_enabled()) {
+          addins.push_back(iter->second.addin_module());
+      }
+    }
+  }
+
   void AddinManager::initialize_sharp_addins()
   {
     if (!sharp::directory_exists (m_addins_prefs_dir))
@@ -190,68 +230,76 @@ namespace gnote {
    
     REGISTER_APP_ADDIN(notebooks::NotebookApplicationAddin);
 
-    m_module_manager.add_path(LIBDIR"/"PACKAGE_NAME"/addins/"PACKAGE_VERSION);
-    m_module_manager.add_path(m_gnote_conf_dir + "/addins");
+    std::string global_path = LIBDIR"/"PACKAGE_NAME"/addins/"PACKAGE_VERSION;
+    std::string local_path = m_gnote_conf_dir + "/addins";
 
-    m_module_manager.load_modules();
+    load_addin_infos(global_path, local_path);
+    std::list<std::string> enabled_addins;
+    get_enabled_addins(enabled_addins);
+    m_module_manager.load_modules(enabled_addins);
 
-    bool global_addins_prefs_loaded = true;
-    Glib::KeyFile global_addins_prefs;
-    try {
-      global_addins_prefs.load_from_file(m_addins_prefs_file);
-    }
-    catch (Glib::Error & not_loaded) {
-      global_addins_prefs_loaded = false;
-    }
+    const sharp::ModuleMap & modules = m_module_manager.get_modules();
+    for(sharp::ModuleMap::const_iterator iter = modules.begin();
+        iter != modules.end(); ++iter) {
 
-    const sharp::ModuleList & list = m_module_manager.get_modules();
-    for(sharp::ModuleList::const_iterator iter = list.begin();
-        iter != list.end(); ++iter) {
-
-      sharp::DynamicModule* dmod = *iter;
+      const std::string & mod_id = get_info_for_module(iter->first).id();
+      sharp::DynamicModule* dmod = iter->second;
       if(!dmod) {
         continue;
       }
 
-      if(global_addins_prefs_loaded &&
-         global_addins_prefs.has_key("Enabled", dmod->id())) {
-        dmod->enabled(global_addins_prefs.get_boolean("Enabled", dmod->id()));
-      }
+      dmod->enabled(true); // enable all loaded modules on startup
+      add_module_addins(mod_id, dmod);
+    }
+  }
 
-      sharp::IfaceFactoryBase * f = dmod->query_interface(NoteAddin::IFACE_NAME);
-      if(f && dmod->is_enabled()) {
-        m_note_addin_infos.insert(std::make_pair(dmod->id(), f));
-      }
+  void AddinManager::add_module_addins(const std::string & mod_id, sharp::DynamicModule * dmod)
+  {
+    sharp::IfaceFactoryBase * f = dmod->query_interface(NoteAddin::IFACE_NAME);
+    if(f && dmod->is_enabled()) {
+      m_note_addin_infos.insert(std::make_pair(mod_id, f));
+    }
 
-      f = dmod->query_interface(AddinPreferenceFactoryBase::IFACE_NAME);
-      if(f) {
-        AddinPreferenceFactoryBase * factory = dynamic_cast<AddinPreferenceFactoryBase*>((*f)());
-        m_addin_prefs.insert(std::make_pair(dmod->id(), factory));
-      }
+    f = dmod->query_interface(AddinPreferenceFactoryBase::IFACE_NAME);
+    if(f) {
+      AddinPreferenceFactoryBase * factory = dynamic_cast<AddinPreferenceFactoryBase*>((*f)());
+      m_addin_prefs.insert(std::make_pair(mod_id, factory));
+    }
 
-      f = dmod->query_interface(ImportAddin::IFACE_NAME);
-      if(f) {
-        ImportAddin * addin = dynamic_cast<ImportAddin*>((*f)());
-        m_import_addins.insert(std::make_pair(dmod->id(), addin));
-      }
+    f = dmod->query_interface(ImportAddin::IFACE_NAME);
+    if(f) {
+      ImportAddin * addin = dynamic_cast<ImportAddin*>((*f)());
+      m_import_addins.insert(std::make_pair(mod_id, addin));
+    }
 
-      f = dmod->query_interface(ApplicationAddin::IFACE_NAME);
-      if(f) {
-        ApplicationAddin * addin = dynamic_cast<ApplicationAddin*>((*f)());
-        m_app_addins.insert(std::make_pair(dmod->id(), addin));
-      }
-      f = dmod->query_interface(sync::SyncServiceAddin::IFACE_NAME);
-      if(f) {
-        sync::SyncServiceAddin * addin = dynamic_cast<sync::SyncServiceAddin*>((*f)());
-        m_sync_service_addins.insert(std::make_pair(dmod->id(), addin));
+    f = dmod->query_interface(ApplicationAddin::IFACE_NAME);
+    if(f) {
+      ApplicationAddin * addin = dynamic_cast<ApplicationAddin*>((*f)());
+      addin->note_manager(m_note_manager);
+      m_app_addins.insert(std::make_pair(mod_id, addin));
+    }
+    f = dmod->query_interface(sync::SyncServiceAddin::IFACE_NAME);
+    if(f) {
+      sync::SyncServiceAddin * addin = dynamic_cast<sync::SyncServiceAddin*>((*f)());
+      m_sync_service_addins.insert(std::make_pair(mod_id, addin));
+    }
+  }
+
+  AddinInfo AddinManager::get_info_for_module(const std::string & module) const
+  {
+    for(AddinInfoMap::const_iterator iter = m_addin_infos.begin();
+        iter != m_addin_infos.end(); ++iter) {
+      if(iter->second.addin_module() == module) {
+        return iter->second;
       }
     }
+    return AddinInfo();
   }
 
   void AddinManager::load_addins_for_note(const Note::Ptr & note)
   {
     if(m_note_addins.find(note) != m_note_addins.end()) {
-      ERR_OUT("trying to load addins when they are already loaded");
+      ERR_OUT(_("Trying to load addins when they are already loaded"));
       return;
     }
     IdAddinMap loaded_addins;
@@ -382,12 +430,13 @@ namespace gnote {
     catch (Glib::Error & not_loaded_ignored) {
     }
 
-    const sharp::ModuleList & list = m_module_manager.get_modules();
-    for(sharp::ModuleList::const_iterator iter = list.begin();
-        iter != list.end(); ++iter) {
-      const sharp::DynamicModule* dmod = *iter;
-      global_addins_prefs.set_boolean("Enabled", dmod->id(),
-                                      dmod->is_enabled());
+    const sharp::ModuleMap & modules = m_module_manager.get_modules();
+    for(AddinInfoMap::const_iterator iter = m_addin_infos.begin();
+        iter != m_addin_infos.end(); ++iter) {
+      const std::string & mod_id = iter->first;
+      sharp::ModuleMap::const_iterator mod_iter = modules.find(iter->second.addin_module());
+      bool enabled = mod_iter != modules.end() && mod_iter->second->is_enabled();
+      global_addins_prefs.set_boolean("Enabled", mod_id, enabled);
     }
 
     Glib::RefPtr<Gio::File> prefs_file = Gio::File::create_for_path(
@@ -398,6 +447,34 @@ namespace gnote {
     prefs_file_stream->write(global_addins_prefs.to_data());
   }
 
+  AddinInfo AddinManager::get_addin_info(const std::string & id) const
+  {
+    AddinInfoMap::const_iterator iter = m_addin_infos.find(id);
+    if(iter != m_addin_infos.end()) {
+      return iter->second;
+    }
+    return AddinInfo();
+  }
+
+  bool AddinManager::is_module_loaded(const std::string & id) const
+  {
+    AddinInfo info = get_addin_info(id);
+    return m_module_manager.get_module(info.addin_module());
+  }
+
+  sharp::DynamicModule *AddinManager::get_module(const std::string & id)
+  {
+    AddinInfo info = get_addin_info(id);
+    sharp::DynamicModule *module = m_module_manager.get_module(info.addin_module());
+    if(!module) {
+      module = m_module_manager.load_module(info.addin_module());
+      if(module) {
+        add_module_addins(id, module);
+      }
+    }
+    return module;
+  }
+
   Gtk::Widget * AddinManager::create_addin_preference_widget(const std::string & id)
   {
     IdAddinPrefsMap::const_iterator iter = m_addin_prefs.find(id);
@@ -406,19 +483,4 @@ namespace gnote {
     }
     return NULL;
   }
-
-  void AddinManager::migrate_addins(const std::string & old_addins_dir)
-  {
-    const Glib::RefPtr<Gio::File> src
-      = Gio::File::create_for_path(old_addins_dir);
-    const Glib::RefPtr<Gio::File> dest
-      = Gio::File::create_for_path(m_gnote_conf_dir);
-
-    try {
-      sharp::directory_copy(src, dest);
-    }
-    catch (const Gio::Error & e) {
-      DBG_OUT("AddinManager: migrating addins: %s", e.what().c_str());
-    }
-  }
 }
