@@ -1,4 +1,4 @@
-/*
+ /*
  * gnote
  *
  * Copyright (C) 2010-2013 Aurimas Cernius
@@ -67,7 +67,7 @@ namespace gnote {
 
       if(notes.size() == 1) {
         // TRANSLATORS: %1% will be replaced by note title
-        message = str(boost::format("Really delete \"%1%\"?") % notes.front()->get_title());
+        message = str(boost::format(_("Really delete \"%1%\"?")) % notes.front()->get_title());
       }
       else {
         // TRANSLATORS: %1% is number of notes
@@ -415,7 +415,7 @@ namespace gnote {
     } 
     catch (const sharp::Exception & e) {
       // Probably IOException or UnauthorizedAccessException?
-      ERR_OUT("Exception while saving note: %s", e.what());
+      ERR_OUT(_("Exception while saving note: %s"), e.what());
       show_io_error_dialog(dynamic_cast<Gtk::Window*>(m_window->host()));
     }
 
@@ -521,7 +521,7 @@ namespace gnote {
     }
     catch(const sharp::Exception &e) 
     {
-      ERR_OUT("Error while saving: %s", e.what());
+      ERR_OUT(_("Error while saving: %s"), e.what());
     }
   }
 
@@ -944,7 +944,7 @@ namespace gnote {
       m_buffer->set_text(text);
     }
     else {
-      ERR_OUT("Setting text content for closed notes not supported");
+      ERR_OUT(_("Setting text content for closed notes not supported"));
     }
   }
 
@@ -1138,7 +1138,7 @@ namespace gnote {
       }
       catch(sharp::Exception & e) {
         // write failure, but not critical
-        ERR_OUT("Failed to update note format: %s", e.what());
+        ERR_OUT(_("Failed to update note format: %s"), e.what());
       }
     }
     return data;
@@ -1279,7 +1279,7 @@ namespace gnote {
     }
     catch(const std::exception & e)
     {
-      ERR_OUT("filesystem error: '%s'", e.what());
+      ERR_OUT(_("Filesystem error: %s"), e.what());
     }
   }
 
